==> tool-sql-1.1.10-sources.jar: io/ciera/tool/sql/ooaofooa/message/impl/InformalAsynchronousMessageSetImpl.java <==
package io.ciera.tool.sql.ooaofooa.message.impl;


import io.ciera.runtime.summit.classes.InstanceSet;
import io.ciera.runtime.summit.exceptions.XtumlException;
import io.ciera.runtime.summit.types.UniqueId;
import io.ciera.tool.sql.ooaofooa.message.AsynchronousMessageSet;
import io.ciera.tool.sql.ooaofooa.message.InformalAsynchronousMessage;
import io.ciera.tool.sql.ooaofooa.message.InformalAsynchronousMessageSet;
import io.ciera.tool.sql.ooaofooa.message.impl.AsynchronousMessageSetImpl;

import java.util.Arrays;
import java.util.List;


public class InformalAsynchronousMessageSetImpl extends InstanceSet<InformalAsynchronousMessageSet,InformalAsynchronousMessage> implements InformalAsynchronousMessageSet {

    // attributes
    @Override
    public void setMsg_ID( UniqueId ref_Msg_ID ) throws XtumlException {
        for ( InformalAsynchronousMessage informalasynchronousmessage : this ) informalasynchronousmessage.setMsg_ID( ref_Msg_ID );
    }


    // selections
    @Override
    public AsynchronousMessageSet R1019_is_a_AsynchronousMessage() throws XtumlException {
        AsynchronousMessageSet asynchronousmessageset = new AsynchronousMessageSetImpl();
        for ( InformalAsynchronousMessage informalasynchronousmessage : this ) asynchronousmessageset.add( informalasynchronousmessage.R1019_is_a_AsynchronousMessage() );
        return asynchronousmessageset;
    }


    @Override
    public InformalAsynchronousMessage nullElement() {
        return InformalAsynchronousMessageImpl.EMPTY_INFORMALASYNCHRONOUSMESSAGE;
    }

    @Override
    public InformalAsynchronousMessageSet emptySet() {
      return new InformalAsynchronousMessageSetImpl();
    }

    @Override
    public InformalAsynchronousMessageSet value() {
        return this;
    }

    @Override
    public List<InformalAsynchronousMessage> elements() {
        return Arrays.asList(toArray(new InformalAsynchronousMessage[0]));
    }

}

==> tool-sql-2.2.0-sources.jar: io/ciera/tool/sql/ooaofooa/message/impl/InformalAsynchronousMessageSetImpl.java <==
package io.ciera.tool.sql.ooaofooa.message.impl;


import io.ciera.runtime.summit.classes.InstanceSet;
import io.ciera.runtime.summit.exceptions.XtumlException;
import io.ciera.runtime.summit.types.UniqueId;
import io.ciera.tool.sql.ooaofooa.message.AsynchronousMessageSet;
import io.ciera.tool.sql.ooaofooa.message.InformalAsynchronousMessage;
import io.ciera.tool.sql.ooaofooa.message.InformalAsynchronousMessageSet;
import io.ciera.tool.sql.ooaofooa.message.impl.AsynchronousMessageSetImpl;

import java.util.Arrays;
import java.util.Comparator;
import java.util.List;


public class InformalAsynchronousMessageSetImpl extends InstanceSet<InformalAsynchronousMessageSet,InformalAsynchronousMessage> implements InformalAsynchronousMessageSet {

    public InformalAsynchronousMessageSetImpl() {
    }

    public InformalAsynchronousMessageSetImpl(Comparator<? super InformalAsynchronousMessage> comp) {
        super(comp);
    }

    // attributes
    @Override
    public void setMsg_ID( UniqueId ref_Msg_ID ) throws XtumlException {
        for ( InformalAsynchronousMessage informalasynchronousmessage : this ) informalasynchronousmessage.setMsg_ID( ref_Msg_ID );
    }


    // selections
    @Override
    public AsynchronousMessageSet R1019_is_a_AsynchronousMessage() throws XtumlException {
        AsynchronousMessageSet asynchronousmessageset = new AsynchronousMessageSetImpl();
        for ( InformalAsynchronousMessage informalasynchronousmessage : this ) asynchronousmessageset.add( informalasynchronousmessage.R1019_is_a_AsynchronousMessage() );
        return asynchronousmessageset;
    }


    @Override
    public InformalAsynchronousMessage nullElement() {
        return InformalAsynchronousMessageImpl.EMPTY_INFORMALASYNCHRONOUSMESSAGE;
    }

    @Override
    public InformalAsynchronousMessageSet emptySet() {
      return new InformalAsynchronousMessageSetImpl();
    }

    @Override
    public InformalAsynchronousMessageSet emptySet(Comparator<? super InformalAsynchronousMessage> comp) {
      return new InformalAsynchronousMessageSetImpl(comp);
    }

    @Override
    public InformalAsynchronousMessageSet value() {
        return this;
    }

    @Override
    public List<InformalAsynchronousMessage> elements() {
        return Arrays.asList(toArray(new InformalAsynchronousMessage[0]));
    }

}
